function tfplist = etsi_noise(tfplist);
%% ===========================================================================
%etsi_noise(tfplist) - Sets up the tfplans for some standard alien systems
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = etsi_noise(ex.tfplist);                Add to existing tfplist
%   tfplan=getList(ex.tfplist,''Model A (SDSL)') ;      Get this SDSL noise
%
%   ex.tfplist = etsi_noise([]);                        Create a new tfplist
%   tfplan=getList(ex.tfplist,'Model E (FTTEx VDSL)');  Get this VDSL noise
%
%  Mask definitions:
%    ETSI VDSL standard Part 2, Version 0.0.5 (1999-06)
%    ETSI STC TM6(98)19 rev. 3 (nov. 26, 1999)
%    ETSI STC TM6 Draft RTS/TM-06006 rev 10a (ADSL), 2001-05
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2000-2001 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : The FSAN xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%               : Gernot Schmid (Gernot.Schmid@arcs.ac.at)
%
% CVS:       $Id: etsi_noise.m,v 1.1 2001/08/20 10:37:01 tono Exp $
%% ===========================================================================
% Change History
%      1999-07-01 (Dab)  Created
%      1999-07-22 (ToNo) Removed the scenario definitions (done on the fly)
%      1999-07-25 (ToNo) Added ETSI Hamband def.
%      1999-08-12 (DaB)  Corrected noise model F (wrong values in ETSI doc)
%      1999-08-19 (DaB)  New structure with modemdef field
%      1999-09-30 (DaB)  Rewritten for new ex struct
%      1999-10-25 (ToNo) Reorganized things into etsi,ansi,itu,fsan definitions
%      1999-11-04 (ToNo) Made it into a function
%      2000-01-19 (GS)   Added SDSL-Noise Models 
%      2000-04-05 (UvAn) Added frequency axis for the call to calcPSD
%      2000-05-26 (UvAn) Added possibillities to fix the bitrate 
%      2000-09-14 (ToNo) Added a few of the ETSI ADSL noises
%      2001-07-04 (ToNo) Added some more of the ETSI ADSL noises
%      2001-07-05 (ToNo) Added all the ETSI ADSL noises provided by Ragnar
%% ===========================================================================

%% ===========================================================================
% Template, order important!

% Default values
def_tfplan.name                  = 'N/A';
def_tfplan.PSD.downstream        = 'N/A';
def_tfplan.PSD.upstream          = 'N/A';
def_tfplan.PSD.active.upstream   = [1 30e6];
def_tfplan.PSD.active.downstream = [1 30e6];
def_tfplan.PSD.PBO.method        = 'None';	% Power back-off method (-=not applicable)
def_tfplan.PSD.PBO.param.len     = 1500;		% PBO parameter {length(m)}
def_tfplan.PSD.PBO.param.freq    = 2e6;	
def_tfplan.PSD.PBO.param.maxlen  = 1500;
def_tfplan.PSD.HAM.active        = 0;
def_tfplan.timeDivision.up       = 1; % Time used in up resp. down lin
def_tfplan.timeDivision.down     = 1;
def_tfplan.fixBitrate.name       = 'None';  % Fixed bitrate method
def_tfplan.fixBitrate.active     = 0;       % 0=inactive, 1=active
def_tfplan.fixBitrate.param      = 'N/A';   
def_tfplan.lcname                = 'N/A';

%% ===========================================================================
% FSAN noise models
%-------------------

% models Alien crosstalk from a disturber shall be coupled with and NEXT
% and FEXT functions 
% Reference TD17, TD20 ETSI TM6 Villach 1999  

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model A (SDSL)';
tmp_tfplan.PSD.downstream='calcPSD([1 -18.2 50e3 -18.2 75e3 -25.4 290e3 -25.4 330e3 -26.1 1.104e6 -26.1 2.50e6 -66.2 4.53e6 -96.5 30e6 -96.5],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1 -18.2 50e3 -18.2 75e3 -25.2 275e3 -25.3 400e3 -40.5 600e3 -54.3 1e6 -71.5 2.75e6 -96.5 30e6 -96.5],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model B (SDSL)';
tmp_tfplan.PSD.downstream='calcPSD([1 -22.2 50e3 -22.2 77e3 -30.2 292e3 -30.3 330e3 -30.8 550e3 -30.8 600e3 -32.6 700e3 -33.6 1.104e6 -33.6 4.53e6 -101 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1 -22.2 50e3 -22.2 71e3 -29.3 145e3 -29.5 175e3 -31.0 274e3 -31.0 400e3 -45.9 600e3 -59.6 1e6 -76.8 2e6 -93.5 3e6 -101 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model C (SDSL)';
tmp_tfplan.PSD.downstream='calcPSD([1 -22.2 50e3 -22.2 74e3 -30.2 292e3 -30.3 330e3 -30.8 550e3 -30.8 600e3 -32.6 700e3 -33.6 1.104e6 -33.6 2e6 -62 15e6 -101 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1	-22.2 50e3 -22.2 71e3 -29.3 145e3 -29.5 175e3 -31.0 274e3 -31.0 450e3 -48.8 900e3 -46.6 1.2e6 -48.2 1.5e6 -52.0 1.78e6 -60.3 16e6 -101 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

%% ===========================================================================
% VDSL

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model A (FTTCab VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.6 100e3 -34.2 292e3 -35.3 400e3 -43.7 1.104e6 -52.6 2.5e6 -99.6 3.637e6 -111.3 30e6 -111.5],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46.3 900e3 -74.5 1.104e6 -79.6 1.4e6 -82 2.5e6 -99.8 3.2e6 -103.5 4.545e6 -103.9 30e6 -103.9],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model B (FTTCab VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.7 100e3 -34.4 135e3 -35.3 139e3 -35.1 292e3 -35.3 400e3 -43.7 552e3 -46.7 956e3 -74.5 1.8e6 -83.3 2e6 -93.1 3.637e6 -111.3 30e6 -111.5],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.1 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46.3 900e3 -74.5 1.104e6 -79.6 1.4e6 -82 2.5e6 -99.8 3.2e6 -103.5 4.545e6 -103.9 30e6 -103.9],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model C (FTTCab VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.6 100e3 -34.2 292e3 -35.3 400e3 -43.6 500e3 -45.4 900e3 -46.5 1.024e6 -46.9 1.4e6 -50.6 1.8e6 -60.6 16.5e6 -103.1 30e6 -109.8],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.1 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46 500e3 -49.1 900e3 -47.1 1.024e6 -47.3 1.4e6 -50.7 1.8e6 -60.6 16.5e6 -101.7 30e6 -103.7],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);


tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model D (FTTEx VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -18.2 50e3 -18.2 75e3 -25.1 117e3 -26.6 138e3 -25.4 290e3 -25.4 330e3 -25.8 1.104e6 -26 2.5e6 -66 4.53e6 -96 30e6 -96.4],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -18.2 50e3 -18.1 75e3 -24.2 275e3 -25.4 400e3 -40.6 600e3 -54.3 1e6 -71.6 2.75e6 -95.7 30e6 -96.4],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model E (FTTEx VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 77e3 -30.9 117e3 -35 140e3 -30.2 292e3 -30.3 330e3 -30.6 550e3 -30.6 600e3 -32.5 700e3 -33.4 1.104e6 -33.5 4.53e6 -100.7 30e6 -101.1],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.0 71e3 -27.8 145e3 -30 175e3 -31 274e3 -31 400e3 -46.5 600e3 -60.3 1.0e6 -77.1 1.4e6 -82.2 2.8e6 -100.3 30e6 -101.1],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model F (FTTEx VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 74e3 -30.3 117e3 -35 140e3 -30.2 292e3 -30.3 330e3 -30.6 550e3 -30.6 600e3 -32.5 700e3 -33.4 1.104e6 -33.5 2.1e6 -64.6 2.45e6 -63.6 16.5e6 -99.1 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([0.004e6 -22.2 0.05e6 -22. 0.071e6 -27.8 0.145e6 -30. 0.175e6 -31. 0.274e6 -31. 0.45e6 -47.5 0.9e6 -45.3 1.2e6 -46.7 1.5e6 -50.4 1.78e6 -58.3 16.5e6 -99.1 30e6 -101.],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

%% ===========================================================================
% EXTENSION to SDSL-Noise Models according to 
% ETSI TM6(98)19 rev. 3 (nov. 26, 1999)

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model SDSL Noise A';
tmp_tfplan.PSD.upstream='calcPSD([1 -20 .015e6 -20 .06e6 -25.2 .276e6 -25.8 .5e6 -51.9 .57e6 -69.5 .6e6 -69.9 .65e6 -62.4 .763e6 -62.4 1e6 -71.5 2.75e6 -96.5 30e6 -96.5] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.downstream='calcPSD([1 -20 .015e6 -20 .03e6 -21.5 .067e6 -27 .125e6 -27 .138e6 -25.7 .4e6 -26.1 1.104e6 -26.1 2.5e6 -66.2 4.55e6 -96.5 30e6 -96.5],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model SDSL Noise B';
tmp_tfplan.PSD.upstream='calcPSD([.000001e6 -25.7 0.015e6 -25.7 .03e6 -26.8 .067e6 -31.2 .142e6 -31.2 .156e6 -32.7 .276e6 -33.2 .4e6 -46 .5e6 -57.9 .57e6 -75.7 .6e6 -76.0 .65e6 -68.3 .763e6 -68.3 1e6 -77.5 2.8e6 -103 30e6 -103],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.downstream='calcPSD([.000001e6 -25.7 .015e6 -25.7 .03e6 -27.4 .045e6 -30.3 .07e6 -36.3 .127e6 -36.3 .138e6 -32.1 .4e6 -32.5 .55e6 -32.5 .61e6 -34.8 .7e6 -35.4 1.104e6 -35.4 4.55e6 -103 30e6 -103],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model SDSL Noise C';
tmp_tfplan.PSD.upstream='calcPSD([.000001e6 -25.7 0.015e6 -25.7 .03e6 -26.8 .067e6 -31.2 .142e6 -31.2 .156e6 -32.7 .276e6 -33.2 .335e6 -42 .45e6 -47.9 .75e6 -45.4 1.04e6 -45.5 2.46e6 -63.6 23.44e6 -103 30e6 -103],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.downstream='calcPSD([.000001e6 -25.7 .015e6 -25.7 .03e6 -27.4 .045e6 -30.3 .07e6 -36.3 .127e6 -36.3 .138e6 -32.1 .4e6 -32.5 .55e6 -32.5 .61e6 -34.8 .7e6 -35.3 1.104e6 -35.3 1.85e6 -58.5 22.4e6 -103 30e6 -103],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);


tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model SDSL Noise D';
tmp_tfplan.PSD.upstream='calcPSD([.000001e6  -300  30e6 -300],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.downstream='calcPSD([.000001e6  -300  30e6 -300],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);


%% ===========================================================================
% ETSI TM6(98)10 rev. 4 (may, 2000)
% ETSI STC TM6 Draft TS 101 388 v1.2.1 (ADSL), 980p12a8, 2001-03

% These data was automatically generated from data privided by
% Ragnar Jonsson (ragnar.jonsson@conexant.com)

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverISDN Noise A';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20.1 14000 -20 30000 -21.5 45000 -24.1 64000 -27.7 105000 -27.6 204000 -28.7 253000 -29.4 255000 -26.7 412000 -27.8 1.104e+06 -27.8 4.543e+06 -96.2 3e+07 -96.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20.1 15000 -20 30000 -21.5 45000 -24.1 65000 -27.6 111000 -27.7 120000 -24.8 275000 -25.3 300000 -29.1 403000 -36 500000 -48.6 614000 -64.8 630000 -64.8 651000 -62.3 755000 -62.4 1.023e+06 -72.7 1.22e+06 -75.5 1.4e+06 -77.9 2.59e+06 -96.2 3e+07 -96.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverISDN Noise B';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.8 2000 -25.8 15000 -25.6 30000 -27.1 45000 -29.6 66000 -32.6 106000 -32.6 200000 -33.6 253000 -34.3 254000 -32.5 303000 -32.9 417000 -34.2 1.104e+06 -34.2 4.439e+06 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.8 2000 -25.8 15000 -25.6 30000 -27.1 44000 -29.6 64000 -32.6 114000 -32.6 120000 -30.7 277000 -31.4 305000 -34.9 389000 -39.3 500000 -53.6 620000 -70.1 633000 -70.1 650000 -68.2 758000 -68.5 1.071e+06 -79.9 1.222e+06 -81.6 1.398e+06 -83.7 2.479e+06 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverISDN Noise C';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.7 15000 -25.6 30000 -27.2 45000 -29.6 62000 -32.6 107000 -32.6 203000 -33.6 253800 -34.3 254000 -32.5 300000 -32.8 409000 -34.2 1.104e+06 -34.2 1.703e+06 -53.6 2.162e+06 -66.2 2.387e+06 -63.7 2.52e+06 -63.6 2.677e+06 -65.5 2e+07 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.6 15000 -25.6 30000 -27.2 45000 -29.6 62000 -32.6 114000 -32.7 120000 -30.7 200000 -31 276000 -31.4 300000 -34.6 377000 -38.7 470000 -47.8 802000 -45.4 1.024e+06 -45.6 1.309e+06 -47.8 1.587e+06 -52.3 1.9e+06 -63 2.011e+06 -76.8 2.283e+06 -63.7 2.492e+06 -63.7 2.716e+06 -66.1 2e+07 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverISDN Noise D';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -79.9 93100 -79.9 209000 -51.9 253990 -38.4 254000 -29.9 1.104e+06 -29.9 3.093e+06 -79.9 4.545e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -79.9 50000 -79.9 80000 -71.8 120000 -27.9 276000 -27.9 614000 -79.9 1.221e+06 -79.9 1.63e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverISDN Noise A';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20 15000 -20 30000 -21.5 66000 -27.7 130000 -27.7 138000 -25.9 204000 -26.1 298000 -26.6 420000 -27.3 1.104e+06 -27.3 4.5e+06 -97.8 3e+07 -97.8 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20 15000 -20 30000 -21.6 66000 -27.7 129000 -27.7 138000 -24.5 276000 -24.9 298000 -28.8 387000 -34.6 500000 -48.6 595000 -62.5 755000 -62.5 1.2e+06 -75.3 2.6e+06 -97.8 3e+07 -97.8 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverISDN Noise B';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.6 15000 -25.6 30000 -27.2 66000 -32.6 130000 -32.7 138000 -31.5 204000 -31.8 298000 -32.5 420000 -33.7 1.104e+06 -33.7 4.5e+06 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.6 15000 -25.6 30000 -27.1 65000 -32.6 129000 -32.7 138000 -30.4 276000 -31 296000 -34.1 381000 -38.8 461000 -48.3 605000 -68.4 755000 -68.4 1.2e+06 -82 2.9e+06 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverISDN Noise C';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.6 15000 -25.6 30000 -27.2 66000 -32.6 130000 -32.7 138000 -31.5 204000 -31.8 298000 -32.5 420000 -33.7 1.104e+06 -33.7 1.85e+06 -58.1 2.3e+07 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.6 15000 -25.6 30000 -27.1 65000 -32.6 129000 -32.7 138000 -30.4 276000 -31 296000 -34.1 381000 -38.8 469000 -48 776000 -45.5 1.03e+06 -45.5 1.41e+06 -48.9 1.8e+06 -57.9 2.3e+07 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverISDN Noise D';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -79.9 50000 -79.9 80000 -71.8 138000 -29.4 1.104e+06 -29.4 3.093e+06 -79.9 4.545e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -79.9 50000 -79.9 80000 -71.8 138000 -27.4 276000 -27.4 614000 -79.9 1.221e+06 -79.9 1.63e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverPOTS Noise A';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20.1 15000 -20 30000 -21.6 45000 -24.1 64000 -27.6 137990 -27.7 138000 -26.1 277000 -26.8 407000 -27.8 1.106e+06 -27.8 4.544e+06 -96.2 3e+07 -96.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20 15000 -20 24000 -20.9 30000 -21 45000 -23 60000 -24.7 138000 -24.9 151000 -28 207000 -28.7 300000 -30.3 358000 -32.8 407000 -36.7 500000 -48.6 594000 -62.3 755000 -62.3 1.059e+06 -73.7 1.221e+06 -75.5 1.4e+06 -77.9 2.532e+06 -96.2 3e+07 -96.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverPOTS Noise B';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.7 15000 -25.6 30000 -27.1 45000 -29.6 65000 -32.6 137990 -32.8 138000 -31.7 272000 -32.5 414000 -34.2 1.103e+06 -34.2 4.36e+06 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.8 15000 -25.6 24000 -26.5 30000 -26.8 61000 -30.5 138000 -30.8 149000 -33 200000 -33.5 308000 -35.2 375000 -38.5 456000 -46.9 605000 -68.4 755000 -68.4 980000 -77.3 1.128e+06 -80.8 1.402e+06 -83.7 2.57e+06 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverPOTS Noise C';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.8 15000 -25.6 30000 -27.2 45000 -29.7 63000 -32.6 137000 -32.8 139000 -31.7 294000 -32.7 417000 -34.2 1.11e+06 -34.2 2.16e+06 -66.1 2.4e+06 -63.6 2.55e+06 -63.8 2e+07 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.8 2000 -25.8 15000 -25.6 22000 -26.4 30000 -26.8 45000 -28.8 60000 -30.5 138000 -30.7 150000 -33 206000 -33.6 338000 -35.7 477000 -47.8 788000 -45.4 1.064e+06 -45.5 1.5e+06 -50.1 1.8e+06 -58.6 2e+07 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverPOTS Noise D';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -87.4 3990 -87.4 4000 -82.4 80000 -62.4 137990 -34.1 138000 -29.9 1.104e+06 -29.9 3.093e+06 -79.9 4.545e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -87.4 3990 -87.4 4000 -82.4 25875 -27.9 138000 -27.9 307000 -79.9 1.221e+06 -79.9 1.63e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverPOTS Noise A';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20 15000 -20 31000 -21.5 63000 -25.6 112000 -25.7 204000 -26.1 298000 -26.6 420000 -27.3 1.104e+06 -27.3 4.5e+06 -97.8 3e+07 -97.8 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20 15000 -20 22000 -20.8 29000 -20.8 61000 -24.4 138000 -24.5 153000 -28.2 220000 -28.9 315000 -30.8 387000 -34.6 461000 -43.4 595000 -62.5 755000 -62.5 1.2e+06 -75.3 2.6e+06 -97.8 3e+07 -97.8 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverPOTS Noise B';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.6 15000 -25.6 31000 -27 63000 -31.3 112000 -31.3 204000 -31.8 298000 -32.5 420000 -33.7 1.104e+06 -33.7 4.5e+06 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.6 15000 -25.6 22000 -26.6 29000 -26.6 61000 -30.3 138000 -30.4 153000 -33.2 220000 -33.9 315000 -35.5 387000 -39.5 461000 -48.3 605000 -68.4 755000 -68.4 1.2e+06 -82 2.9e+06 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverPOTS Noise C';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.6 15000 -25.6 31000 -27 63000 -31.3 112000 -31.3 204000 -31.8 298000 -32.5 420000 -33.7 1.104e+06 -33.7 1.85e+06 -58.1 2.3e+07 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.6 15000 -25.6 22000 -26.6 29000 -26.6 61000 -30.3 138000 -30.4 153000 -33.2 220000 -33.9 315000 -35.5 387000 -39.5 469000 -48 776000 -45.5 1.03e+06 -45.5 1.41e+06 -48.9 1.8e+06 -57.9 2.3e+07 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverPOTS Noise D';
tmp_tfplan.PSD.downstream= 'calcPSD([0 -87.4 3990 -87.4 4000 -82.4 25875 -29.4 1.104e+06 -29.4 3.093e+06 -79.9 4.545e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -87.4 3990 -87.4 4000 -82.4 25875 -27.4 138000 -27.4 307000 -79.9 1.221e+06 -79.9 1.63e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);
